# Copyright 2010-2014 Michael Frank <msfrank@syntaxjockey.com>
#
# This file is part of Pesky.  Pesky is BSD-licensed software;
# for copyright information see the LICENSE file.

class DefaultsError(Exception):
    pass

class UndefinedDefault(DefaultsError):
    pass
